==> genomeIntervals_1.0.1.zip: genomeIntervals/doc/genomeIntervals.R <==
###################################################
### chunk number 1: set_width
###################################################
options( width = 80 )


###################################################
### chunk number 2: classes
###################################################
library( genomeIntervals )
data("gen_ints")
i


###################################################
### chunk number 3: ends
###################################################
i[,1]
i[,2]
closed(i)
closed(i)[2,2] <- FALSE


###################################################
### chunk number 4: <quick.closure
###################################################
i2 <- i
closed(i2) <- c( TRUE, FALSE )
i2


###################################################
### chunk number 5: seqname.strand
###################################################
seq_name(i)
strand(i)
strand(i)[2] <- "-"


###################################################
### chunk number 6: combine
###################################################
j
c( i[1:3,], j[1:2,] )


###################################################
### chunk number 7: annotation
###################################################
annotation(i)
annotation(i)$myannot = rep( c("my", "annot"), length=nrow(i) )
annotation(i[2:3,])


###################################################
### chunk number 8: annotationColumns
###################################################
i$myannot
i[["myannot"]]


###################################################
### chunk number 9: close-intervals
###################################################
close_intervals(i)


###################################################
### chunk number 10: size
###################################################
size(i)


###################################################
### chunk number 11: new
###################################################
new(
    "Genome_intervals_stranded",
    matrix(c(1, 2, 2, 5), ncol = 2),
    closed = TRUE,
    annotation = data.frame(
            seq_name = c("chr01","chr02"),
            inter_base = FALSE,
            strand = factor( c("+", "+"), levels=c("+", "-") )
    )
)


###################################################
### chunk number 12: intervalOverlap
###################################################
interval_overlap( from=i, to=j )


###################################################
### chunk number 13: interval-union
###################################################
interval_union(i)


###################################################
### chunk number 14: setoperations
###################################################
interval_intersection(i,j)
interval_complement(j[1:2,])


###################################################
### chunk number 15: distance
###################################################
distance_to_nearest(i,j)


###################################################
### chunk number 16: inter-base
###################################################
k
inter_base(k)
k[inter_base(k),]


###################################################
### chunk number 17: size.inter-base
###################################################
size(k)


###################################################
### chunk number 18: intervalOverlap.inter-base
###################################################
interval_overlap(j,k)


###################################################
### chunk number 19: distance.inter-base
###################################################
distance_to_nearest(j,k)


###################################################
### chunk number 20: setoperations.inter-base
###################################################
interval_union(k)
interval_intersection(k,j)
interval_complement(k[1:2,])


###################################################
### chunk number 21: loadgff
###################################################
libPath <- installed.packages()["genomeIntervals", "LibPath"]
filePath <- file.path(
        libPath,
        "genomeIntervals",
        "example_files"
)

gff <- readGff3( 
        file.path( filePath, "sgd_simple.gff" ), 
        isRightOpen=FALSE 
)
idpa = getGffAttribute( gff, c( "ID", "Parent" ) )
head(idpa)


###################################################
### chunk number 22: sessionInfo
###################################################
si <- as.character( toLatex( sessionInfo() ) )
cat( si[ -grep( "Locale", si ) ], sep = "\n" )

==> genomeIntervals_1.6.0.zip: genomeIntervals/doc/genomeIntervals.R <==
###################################################
### chunk number 1: set_width
###################################################
#line 29 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
options( width = 80 )


###################################################
### chunk number 2: classes
###################################################
#line 62 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
library( genomeIntervals )
data("gen_ints")
i


###################################################
### chunk number 3: ends
###################################################
#line 72 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
i[,1]
i[,2]
closed(i)
closed(i)[2,2] <- FALSE


###################################################
### chunk number 4: <quick.closure
###################################################
#line 82 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
i2 <- i
closed(i2) <- c( TRUE, FALSE )
i2


###################################################
### chunk number 5: seqname.strand
###################################################
#line 90 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
seq_name(i)
strand(i)
strand(i)[2] <- "-"


###################################################
### chunk number 6: combine
###################################################
#line 100 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
j
c( i[1:3,], j[1:2,] )


###################################################
### chunk number 7: annotation
###################################################
#line 108 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
annotation(i)
annotation(i)$myannot = rep( c("my", "annot"), length=nrow(i) )
annotation(i[2:3,])


###################################################
### chunk number 8: annotationColumns
###################################################
#line 115 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
i$myannot
i[["myannot"]]


###################################################
### chunk number 9: close-intervals
###################################################
#line 124 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
close_intervals(i)


###################################################
### chunk number 10: size
###################################################
#line 130 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
size(i)


###################################################
### chunk number 11: new
###################################################
#line 137 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
new(
    "Genome_intervals_stranded",
    matrix(c(1, 2, 2, 5), ncol = 2),
    closed = TRUE,
    annotation = data.frame(
            seq_name = c("chr01","chr02"),
            inter_base = FALSE,
            strand = factor( c("+", "+"), levels=c("+", "-") )
    )
)


###################################################
### chunk number 12: intervalOverlap
###################################################
#line 157 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
interval_overlap( from=i, to=j )


###################################################
### chunk number 13: interval-union
###################################################
#line 169 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
interval_union(i)


###################################################
### chunk number 14: setoperations
###################################################
#line 178 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
interval_intersection(i,j)
interval_complement(j[1:2,])


###################################################
### chunk number 15: distance
###################################################
#line 191 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
distance_to_nearest(i,j)


###################################################
### chunk number 16: inter-base
###################################################
#line 213 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
k
inter_base(k)
k[inter_base(k),]


###################################################
### chunk number 17: size.inter-base
###################################################
#line 221 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
size(k)


###################################################
### chunk number 18: intervalOverlap.inter-base
###################################################
#line 227 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
interval_overlap(j,k)


###################################################
### chunk number 19: distance.inter-base
###################################################
#line 235 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
distance_to_nearest(j,k)


###################################################
### chunk number 20: setoperations.inter-base
###################################################
#line 241 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
interval_union(k)
interval_intersection(k,j)
interval_complement(k[1:2,])


###################################################
### chunk number 21: loadgff
###################################################
#line 256 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
libPath <- installed.packages()["genomeIntervals", "LibPath"]
filePath <- file.path(
        libPath,
        "genomeIntervals",
        "example_files"
)

gff <- readGff3( 
        file.path( filePath, "sgd_simple.gff" ), 
        isRightOpen=FALSE 
)
idpa = getGffAttribute( gff, c( "ID", "Parent" ) )
head(idpa)


###################################################
### chunk number 22: sessionInfo
###################################################
#line 278 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpHHM4EG/R.INSTALL1f643596/genomeIntervals/inst/doc/genomeIntervals.Rnw"
si <- as.character( toLatex( sessionInfo() ) )
cat( si[ -grep( "Locale", si ) ], sep = "\n" )
